@@ -1,46 +1,33 @@
-from typing import OrderedDict, Tuple
-import requests
-from jinja2 import (
-    Environment,
-    PackageLoader,
-    select_autoescape
-)
-from csc_recorder.APIHandler import APIHandler
-import xmltodict
 import json
+from typing import OrderedDict, Tuple
 
+import requests
+import xmltodict
+from jinja2 import Environment, PackageLoader, select_autoescape
+
+from csc_recorder.APIHandler import APIHandler
 
 env = Environment(
-    loader=PackageLoader("csc_recorder.CSC"),
-    autoescape=select_autoescape()
+    loader=PackageLoader("csc_recorder.CSC"), autoescape=select_autoescape()
 )
 
+
 class CSCRecorder(APIHandler):
-    TEST_URL = 'https://ep4-uat.erecording.com/api'
-    PROD_URL = 'http://'
-
-    def __init__(self, username, password, test=False):
-        self.host = self.TEST_URL if not test else self.PROD_URL
-
-        self.api_handler = APIHandler(
-            self.host, 
-            username,
-            password,
-            headers={
-                'Content-Type': 'application/xml'
-            }
+    def __init__(self, host, username, password):
+        self._api_handler = APIHandler(
+            host, username, password, headers={"Content-Type": "application/xml"}
         )
 
     def _clean_response(self, r: str) -> str:
-        r = r.encode('ascii', 'ignore').decode('unicode_escape')
-        r = r.replace('<?xml version="1.0" encoding="UTF-8"?>', '')
+        r = r.encode("ascii", "ignore").decode("unicode_escape")
+        r = r.replace('<?xml version="1.0" encoding="UTF-8"?>', "")
         r = r[1:]
         r = r[:-1]
         return r
 
     def _parse_xml_string(self, xml):
         ...
-    
+
     def _get_fips(self):
         ...
 
@@ -52,10 +39,11 @@ class CSCRecorder(APIHandler):
         params: dict = {},
         service_type: str = None,
         no_document: bool = False,
+        debug: bool = False,
     ) -> Tuple[OrderedDict, requests.Response]:
         """
         Sends a request to generate a package to CSC eRecorder
-        
+
         Ex param dictionary:
         params = {
             "document_name": "some_name",
@@ -66,85 +54,82 @@ class CSCRecorder(APIHandler):
         :param fips: the FIPS code of the county
         :param assigned_office: the name of the office to assign the package to
         :param params: dict of parameters to send to CSC
-        :param service_type: currently only 'paperfulfillment' option 
+        :param service_type: currently only 'paperfulfillment' option
         :param no_document: bool, if true, will send no document info
         :return: dict of package information
         """
-        template = env.get_template('CreatePackage.xml')
-        params['no_document'] = no_document
-        params['client_package_id'] = client_package_id
-        params['fips'] = fips # TODO generate FIPS
-        params['assigned_office'] = assigned_office
+        template = env.get_template("CreatePackage.xml")
+        params["no_document"] = no_document
+        params["client_package_id"] = client_package_id
+        params["fips"] = fips  # TODO generate FIPS
+        params["assigned_office"] = assigned_office
         payload = template.render(**params)
 
-        print(payload)
+        if debug:
+            print(payload)
 
         url = "/v1/package?contentType=xml"
-        if service_type: url += f"&serviceType={service_type}"
 
-        response = self.api_handler.send_request(
-            "POST", url, payload
-        )
+        if service_type:
+            url = f"{url}&serviceType={service_type}"
+
+        response = self._api_handler.send_request("POST", url, payload)
 
         cleaned_response = self._clean_response(str(response.text))
-        
+
         return xmltodict.parse(cleaned_response), response
-    
+
     def get_document_type(self, fips: str) -> Tuple[dict, requests.Response]:
-        response = self.api_handler.send_request(
-            "GET", f"/v1/documentType/{fips}"
-        )
-        
+        response = self._api_handler.send_request("GET", f"/v1/documentType/{fips}")
+
         return json.loads(response.content), response
-    
+
     def get_package_status(self, binder_id: str) -> Tuple[dict, requests.Response]:
         """
         Returns a packages status with file and fees.
 
         :param binder_id: the binder ID of the package
         """
-        response = self.api_handler.send_request(
+        response = self._api_handler.send_request(
             "GET",
-            (f"/v3/package/{binder_id}?returnFileType=pdf"
-            "&embed=true&contentType=json&includeImage=true")
+            (
+                f"/v3/package/{binder_id}?returnFileType=pdf"
+                "&embed=true&contentType=json&includeImage=true"
+            ),
         )
 
         return xmltodict.parse(response.content), response
-    
+
     def get_mortgage_tax_req(self, county_id: str) -> Tuple[dict, requests.Response]:
-        """
-        
-        """
-        response = self.api_handler.send_request(
+        """ """
+        response = self._api_handler.send_request(
             "GET",
-            (f"/v1/county/{county_id}"
-            "/AdditionalMortgageTaxNoRecordingFee/requirements")
+            (
+                f"/v1/county/{county_id}"
+                "/AdditionalMortgageTaxNoRecordingFee/requirements"
+            ),
         )
         return json.loads(response.content), response
-    
+
     def get_assigned_office(self) -> Tuple[dict, requests.Response]:
         """
         Returns the current selected office from the CSC Platform.
         """
-        response = self.api_handler.send_request(
-            "GET",
-            "/v1/office/assigned"
-        )
+        response = self._api_handler.send_request("GET", "/v1/office/assigned")
 
         return json.loads(response.content), response
-    
+
     def get_offices(self) -> Tuple[dict, requests.Response]:
         """
         Returns all offices that have been created for your account.
         """
-        response = self.api_handler.send_request(
-            "GET",
-            "/v1/office"
-        )
+        response = self._api_handler.send_request("GET", "/v1/office")
 
         return json.loads(response.content), response
-    
-    def get_state_offices(self, state: str, service_type=None) -> Tuple[dict, requests.Response]:
+
+    def get_state_offices(
+        self, state: str, service_type=None
+    ) -> Tuple[dict, requests.Response]:
         """
         Returns a list of county offices for that given state.
 
@@ -152,10 +137,9 @@ class CSCRecorder(APIHandler):
         :param service_type: the service type to filter by Ex: 'paper'
         """
         url = f"/v1/state/{state}"
-        if service_type: url += f"?serviceType={service_type}" 
+        if service_type:
+            url += f"?serviceType={service_type}"
 
-        response = self.api_handler.send_request(
-            "GET", url
-        )
+        response = self._api_handler.send_request("GET", url)
 
-        return json.loads(response.content), response
\ No newline at end of file
+        return json.loads(response.content), response
